# Generated by roxygen2: do not edit by hand

export(compute_central_graph)
export(compute_distance)
export(compute_edge_frequencies)
export(compute_edge_pvalues)
export(compute_test_statistic)
export(generate_category_graphs)
export(generate_community_graph)
export(generate_random_graph)
export(get_critical_nodes)
export(identify_critical_links)
export(plot_critical_edges)
export(rank_edges)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(stats,chisq.test)
importFrom(stats,fisher.test)
importFrom(stats,p.adjust)
importFrom(stats,prop.test)
importFrom(stats,rbinom)
importFrom(stats,runif)
